@@ -4,15 +4,17 @@
 # Python `imodels` package for interpretable models compatible with scikit-learn.
 # Github repo available [here](https://github.com/csinva/interpretability-implementations-demos).
 
+import os
+
 # from .tree.iterative_random_forest.iterative_random_forest import IRFClassifier
 # from .tree.optimal_classification_tree import OptimalTreeModel
 from .tree.cart_wrapper import GreedyTreeClassifier
-from .tree.gosdt_wrapper import GlobalSparseTreeClassifier
+from .tree.gosdt.pygosdt import OptimalTreeClassifier
 from .algebraic.slim import SLIMRegressor, SLIMClassifier
 from .discretization.discretizer import RFDiscretizer, BasicDiscretizer
 from .discretization.mdlp import MDLPDiscretizer, BRLDiscretizer
 from .rule_list.bayesian_rule_list.bayesian_rule_list import BayesianRuleListClassifier
-from .rule_list.corels_wrapper import CorelsRuleListClassifier
+from .rule_list.corels_wrapper import OptimalRuleListClassifier
 from .rule_list.greedy_rule_list import GreedyRuleListClassifier
 from .rule_list.one_r import OneRClassifier
 from .rule_set import boosted_rules
