@@ -1,8 +1,7 @@
-from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin
-from sklearn.utils.multiclass import check_classification_targets
-from sklearn.utils.validation import check_X_y, check_array, check_is_fitted
 from typing import List
 
+from sklearn.base import ClassifierMixin, RegressorMixin
+
 from imodels.rule_set.rule_fit import RuleFit
 from imodels.util.convert import itemsets_to_rules
 from imodels.util.extract import extract_fpgrowth
@@ -13,7 +12,10 @@ class FPLasso(RuleFit):
     def __init__(self,
                  minsupport=0.1,
                  maxcardinality=2,
+                 disc_strategy='mdlp',
+                 disc_kwargs={},
                  verbose=False,
+                 n_estimators=100,
                  tree_size=4,
                  sample_fract='default',
                  max_rules=2000,
@@ -23,10 +25,10 @@ class FPLasso(RuleFit):
                  lin_standardise=True,
                  exp_rand_tree_size=True,
                  include_linear=True,
-                 alphas=None,
-                 cv=3,
+                 alpha=None,
                  random_state=None):
-        super().__init__(tree_size,
+        super().__init__(n_estimators,
+                         tree_size,
                          sample_fract,
                          max_rules,
                          memory_par,
@@ -35,9 +37,10 @@ class FPLasso(RuleFit):
                          lin_standardise,
                          exp_rand_tree_size,
                          include_linear,
-                         alphas,
-                         cv,
+                         alpha,
                          random_state)
+        self.disc_strategy = disc_strategy
+        self.disc_kwargs = disc_kwargs
         self.minsupport = minsupport
         self.maxcardinality = maxcardinality
         self.verbose = verbose
@@ -49,10 +52,12 @@ class FPLasso(RuleFit):
 
     def _extract_rules(self, X, y) -> List[str]:
         itemsets = extract_fpgrowth(X, y,
-                                    feature_labels=self.feature_placeholders,
+                                    feature_names=self.feature_placeholders,
                                     minsupport=self.minsupport,
                                     maxcardinality=self.maxcardinality,
                                     undiscretized_features=self.undiscretized_features,
+                                    disc_strategy=self.disc_strategy,
+                                    disc_kwargs=self.disc_kwargs,
                                     verbose=self.verbose)[0]
         return itemsets_to_rules(itemsets)
 
