@@ -1,6 +1,7 @@
 import random
+import numpy as np
 
-from imodels import *
+from imodels import *  # noqa: F403
 
 
 class TestClassClassificationBinary:
@@ -13,8 +14,12 @@ class TestClassClassificationBinary:
         self.n = 40
         self.p = 2
         self.X_classification_binary = np.random.randn(self.n, self.p)
-        self.y_classification_binary = (self.X_classification_binary[:, 0] > 0).astype(int)  # y = x0 > 0
-        self.y_classification_binary[-2:] = 1 - self.y_classification_binary[-2:]  # flip labels for last few
+        
+        # y = x0 > 0
+        self.y_classification_binary = (self.X_classification_binary[:, 0] > 0).astype(int)
+
+        # flip labels for last few
+        self.y_classification_binary[-2:] = 1 - self.y_classification_binary[-2:]
 
     def test_classification_binary(self):
         '''Test imodels on basic binary classification task
@@ -24,7 +29,7 @@ class TestClassClassificationBinary:
             FPLassoClassifier, SkopeRulesClassifier,
             FPSkopeClassifier, BoostedRulesClassifier,
             OneRClassifier, SlipperClassifier,
-            GreedyTreeClassifier
+            GreedyTreeClassifier, OptimalTreeClassifier
         ]:  # IRFClassifier, SLIMClassifier, BayesianRuleSetClassifier
 
             init_kwargs = {}
@@ -43,12 +48,13 @@ class TestClassClassificationBinary:
             assert preds.size == self.n, 'predict() yields right size'
 
             # test preds_proba()
-            if not model_type == CorelsRuleListClassifier:
+            if model_type not in {OptimalRuleListClassifier, OptimalTreeClassifier}:
                 preds_proba = m.predict_proba(X)
                 assert len(preds_proba.shape) == 2, 'preds_proba has 2 columns'
                 assert preds_proba.shape[1] == 2, 'preds_proba has 2 columns'
                 assert np.max(preds_proba) < 1.1, 'preds_proba has no values over 1'
-                assert (np.argmax(preds_proba, axis=1) == preds).all(), "predict_proba and predict correspond"
+                assert (np.argmax(preds_proba, axis=1) == preds).all(), ("predict_proba and "
+                                                                         "predict agree")
 
             # test acc
             acc_train = np.mean(preds == self.y_classification_binary)
